@@ -11,14 +11,14 @@ fn base() {
     assert_eq!(PUB.send(2), 2);
     assert_eq!(PUB.send(3), 2);
     assert_eq!(PUB.send(4), 0); // full
-    assert_eq!(sub1.recv().unwrap(), 1);
-    assert_eq!(sub2.recv().unwrap(), 1);
+    assert_eq!(sub1.try_recv().unwrap(), 1);
+    assert_eq!(sub2.try_recv().unwrap(), 1);
     assert_eq!(PUB.send(5), 2);
-    assert_eq!(sub1.recv().unwrap(), 2);
-    assert_eq!(sub2.recv().unwrap(), 2);
+    assert_eq!(sub1.try_recv().unwrap(), 2);
+    assert_eq!(sub2.try_recv().unwrap(), 2);
     drop(sub2);
     assert_eq!(PUB.send(6), 1);
-    assert_eq!(sub1.recv().unwrap(), 3);
-    assert_eq!(sub1.recv().unwrap(), 5);
-    assert_eq!(sub1.recv().unwrap(), 6);
+    assert_eq!(sub1.try_recv().unwrap(), 3);
+    assert_eq!(sub1.try_recv().unwrap(), 5);
+    assert_eq!(sub1.try_recv().unwrap(), 6);
 }
